Class: Hash
- Inherits:
-
Object
- Object
- Hash
- Defined in:
- lib/ppds/tumblr.rb
Instance Method Summary collapse
-
#stringify_keys! ⇒ Object
taken from Ruby on Rails modified to replace undercores with dashes.
Instance Method Details
#stringify_keys! ⇒ Object
taken from Ruby on Rails modified to replace undercores with dashes
123 124 125 126 127 128 |
# File 'lib/ppds/tumblr.rb', line 123 def stringify_keys! keys.each do |key| self[key.to_s.gsub(/_/, '-')] = delete(key) end self end |